<?php

declare(strict_types=1);

namespace IQDEV\Packages\DoctrineHttpFilter\Filter;

use Doctrine\ORM\QueryBuilder;
use IQDEV\Packages\DoctrineHttpFilter\Exception\FilterParameterValueIsNullException;
use IQDEV\Packages\DoctrineHttpFilter\HttpFilter;

final class Date extends HttpFilter
{
    /** @throws FilterParameterValueIsNullException */
    public function addToQuery(QueryBuilder $queryBuilder): QueryBuilder
    {
        $queryBuilder->where(
            'SUBSTRING(' . $this->getColumn() . ', 0, 11) = :' . $this->getParameterKey(),
        );

        if (is_null($this->getHttpValue())) {
            throw new FilterParameterValueIsNullException($this->field);
        }

        if (! \DateTimeImmutable::createFromFormat('Y-m-d', $this->getHttpValue())) {
            throw new FilterParameterValueIsNullException($this->field);
        }

        $queryBuilder->setParameter($this->getParameterKey(), $this->getHttpValue());

        return $queryBuilder;
    }
}
